<template>
  <div class="notice">
    <el-dialog
        v-model="dialogVisible"
        :title="state.title"
        width="550px"
        :before-close="handleClose"
        :close-on-press-escape="false"
        :close-on-click-modal="false"
    >
      <el-form :model="state.form" size="default" ref="superRef" :rules="state.formRules" label-width="180px" >
        <el-form-item label="企业:"  prop="companyName" v-if="state.title !== '修改密码'">
          <el-input v-model.trim="state.form.companyName" disabled></el-input>
        </el-form-item>
        <el-form-item label="姓名:"  prop="name" v-if="state.title !== '修改密码'">
          <el-input v-model.trim="state.form.name" :disabled="disabled" placeholder="请输入姓名" ></el-input>
        </el-form-item>
        <el-form-item label="性别:"  prop="sex" v-if="state.title !== '修改密码'">
          <el-radio-group v-model="state.form.sex"  :disabled="disabled">
            <el-radio :label="0">男</el-radio>
            <el-radio :label="1">女</el-radio>
          </el-radio-group>
        </el-form-item>
        <el-form-item label="身份证号:"  prop="idNo" v-if="state.title !== '修改密码'">
          <el-input v-model.trim="state.form.idNo" maxlength="18" :disabled="disabled" placeholder="请输入身份证号" ></el-input>
        </el-form-item>
        <el-form-item label="手机号（登录用户名）:" prop="phone" v-if="state.title !== '修改密码'" >
          <el-input v-model.trim="state.form.phone" :maxlength="11" :disabled="disabled" placeholder="请输入手机号"></el-input>
        </el-form-item>
        <el-form-item label="密码:" prop="password" v-if="state.title == '新增' || state.title == '修改密码'">
          <el-input v-model.trim="state.form.password" type="password" show-password placeholder="请输入密码"></el-input>
        </el-form-item>
        <el-form-item label="重复密码:" prop="confirmPassword" v-if="state.title == '新增' || state.title == '修改密码'">
          <el-input v-model.trim="state.form.confirmPassword" type="password" show-password placeholder="请输入确认密码"></el-input>
        </el-form-item>
<!--        <el-form-item label="所属部门账号:"  prop="createBy" v-if="state.title !== '修改密码' && (currentUserType === 1 || currentUserType === 4)">-->
<!--          <el-select-->
<!--              clearable-->
<!--              v-model="state.form.createBy"-->
<!--              filterable-->
<!--              remote-->
<!--              @change="selectValue"-->
<!--              reserve-keyword-->
<!--              placeholder="请输入部门账号名称"-->
<!--              remote-show-suffix-->
<!--              :remote-method="getDeptUserList"-->
<!--              :loading="loading"-->
<!--              style="width: 100%"-->
<!--          >-->
<!--            <el-option-->
<!--                v-for="item in state.deptUserList"-->
<!--                :key="item.id"-->
<!--                :label="item.name"-->
<!--                :value="item.name"-->
<!--            />-->
<!--          </el-select>-->
<!--        </el-form-item>-->
        <el-form-item label="部门:"  prop="deptId" v-if="state.title !== '修改密码'">
          <el-select
              v-model="state.form.deptId"
              placeholder="请选择部门"
              style="width: 100%"
          >
            <el-option
                v-for="item in state.deptList"
                :key="item.deptId"
                :label="item.deptName"
                :value="item.deptId"
            />
          </el-select>
        </el-form-item>
<!--        <el-form-item label="工号:"  prop="empno" v-if="state.title !== '修改密码'">-->
<!--          <el-input v-model.trim="state.form.empno" :disabled="disabled" placeholder="请输入工号" ></el-input>-->
<!--        </el-form-item>-->
<!--        <el-form-item label="岗位:"  prop="post" v-if="state.title !== '修改密码'">-->
<!--          <el-input v-model.trim="state.form.post" :disabled="disabled" placeholder="请输入岗位" ></el-input>-->
<!--        </el-form-item>-->
        <el-form-item label="职务:"  prop="duty" v-if="state.title !== '修改密码'">
          <el-input v-model.trim="state.form.duty" :disabled="disabled" placeholder="请输入职务" ></el-input>
        </el-form-item>
      </el-form>
      <template #footer v-if="state.title !='查看'">
        <span class="dialog-footer">
            <el-button @click="handleClose" size="default">取 消</el-button>
            <el-button type="primary"  @click="onSubmit" size="default" v-preReClick>确认</el-button>
        </span>
      </template>
    </el-dialog>
  </div>
</template>
<script setup>
import {reactive, ref, toRefs, defineEmits, nextTick, onMounted} from 'vue'
import { View } from "@element-plus/icons-vue";
import scorllSelect from '@/components/scrollSelect/index.vue'
import {ElMessage, ElMessageBox} from "element-plus";
import {verifyPhone, verifyPwd, verifyUsername} from "@/utils/validate";
import { checkUserName, checkPhone } from "@/api/login"
import {changeCompany, resetPwd} from "@/api/onlineEducation/student"
import {Base64} from "js-base64"
import Cookies from "js-cookie";
import {addStudent, checkStuIdNo, checkStuPhone, editStudent} from "@/api/onlineEducation/student";
import {getCompany} from "@/api/onlineEducation/company";
import {getUser} from "@/api/onlineEducation/user";
import {getDept} from "@/api/qualityObjectives/object";
const emit = defineEmits(["getList"]);
const dialogVisible = ref(false)
const superRef = ref(null)
const scrollRef = ref(null)



const equalToPassword = (rule, value, callback) => {
  if (state.form.password !== value) {
    callback(new Error("两次输入的密码不一致"));
  } else {
    callback();
  }
};

const validateUserPhone = (rule, value, callback)=>{
  if(value === ''){
    callback(new Error('请输入手机号'))
  }else if(state.title === '编辑' && value === startPhone.value){
    callback()
  } else if(!verifyPhone(value)){
    callback(new Error('手机号格式有误'))
  }else{
    let param = {}
    if(state.title === '新增') {
      param = {
        phone:value
      }
    }else if(state.title === '编辑'){
      param = {
        phone:value,
        id: state.form.id
      }
    }
    checkStuPhone(param).then((res)=>{
      if(res.data == false){
        callback(new Error('手机号已被占用，请更换其他手机号'))
      }else{
        callback()
      }
    })
  }
}

let validatePwd = (rule, value, callback)=>{
  if(value === ''){
    callback(new Error('请输入密码'))
  }else{
    if(!verifyPwd(value)){
      callback(new Error('密码须包含字母、数字、特殊字符，长度在6-16之间'))
    }else{
      callback()
    }
  }
}
let validateIdNo = (rule, value, callback)=>{
  if(value === ''){
    // callback(new Error('请输入身份证号'))
    callback()
  }else if(state.title === '编辑' && value === startIdNo.value){
    callback()
  }else{
    let param = {}
    if(state.title === '新增') {
      param = {
        idNo:value
      }
    }else if(state.title === '编辑'){
      param = {
        idNo:value,
        id: state.form.id
      }
    }
    checkStuIdNo(param).then((res)=>{
      if(res.data.status == 1){
        callback(new Error('身份证号在该企业已被占用，请更换其他身份证号'))
      }else if(res.data.status == 2){
        if(state.title == '新增'){
          ElMessageBox.confirm(
              `该人员 ${state.form.name} (身份证号： ${state.form.idNo} )与 ${res.data.companyName} 已经绑定，确定将该人员的责任归属变更到贵公企业？`,
              '提示',
              {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning',
                icon: ''
              }
          )
          .then(() => {
            const param = {
              companyId: state.form.companyId,
              studentId: res.data.studentId
            }
            changeCompany(param).then((res) => {
              if(res.code == 200){
                ElMessage({
                  type: 'success',
                  message: '变更成功',
                })
                emit('getList')
                handleClose()

                callback()
              }else {
                ElMessage.warning(res.message)
              }
            })
          })
        }else {
          callback(new Error('身份证号在其他企业已被占用，请更换身份证号'))
        }
      }else {
        callback()
      }
    })
  }
}


const state = reactive({
  title: '',
  form: {
    id: null,
    name: '',
    phone: '',
    password: '',
    confirmPassword: '',
    sex: 0,
    companyId: null,
    empno: '',
    post: '',
    duty: '',
    idNo: '',
    createId: null,
    createBy: '',
    userType: null,
    deptId: null

  },
  formRules:{
    name: [{ required: true, message: '请输入姓名', trigger: 'blur' }],
    password: [{ required: true, validator: validatePwd, trigger: 'blur' }],
    confirmPassword: [{ required: true, validator: equalToPassword, trigger: 'blur' }],
    phone: [{ required: true, validator: validateUserPhone, trigger: 'blur' }],
    idNo: [{ validator: validateIdNo, trigger: 'blur' }],
    // createBy: [{ required: true, message: '请输入所属部门名称', trigger: 'blur' }],

  },
  isAdmin: false,
  deptUserList: [],
  deptList: []

})
const startPhone = ref('');
const startIdNo = ref('');
const UisMounted = ref(false);
onMounted(async () => {
  UisMounted.value = true;
  await getDeptList()

});
const getDeptList = async () => {
  const param = {
    pageNum: 1,
    pageSize: 999,
    companyId: state.form.companyId
  }
  const res = await getDept(param)
  if(res.code === 200){
    state.deptList = res.data
  }
}
const currentUserType = ref(null)
const disabled = ref(false);
const openDialog = async (type, value) => {
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  console.log("userInfo",userInfo)
  currentUserType.value = userInfo.userType
  if(userInfo.userType === 0){
    state.isAdmin = true;
    state.form.userType = 0;
  }else {
    state.isAdmin = false;
    state.form.companyId = userInfo.companyId;
    state.form.companyName = userInfo.companyName;
    state.form.userType = userInfo.userType;
  }
  if(userInfo.userType === 1 || userInfo.userType === 4) {
    await getDeptUserList("")
  }else if(userInfo.userType === 2){
    state.form.createId = userInfo.id
    state.form.createBy = userInfo.name
  }
  state.title = type === 'add' ? '新增' : type ==='edit' ? '编辑' : type ==='pwd' ? '修改密码' : '查看' ;
  if(type === 'edit' || type === 'view') {
    if( type === 'view'){
      disabled.value = true;
    }
    startPhone.value = value.phone
    startIdNo.value = value.idNo
    state.form =  JSON.parse(JSON.stringify(value))
    state.form.companyName = value.company.name;
    console.log("ba",state.form)
  }
  if(type == 'pwd'){
    state.form.id = value.id
  }
  dialogVisible.value = true
}
const onSubmit = async () => {
  const valid = await superRef.value.validate();
  if(valid){
    if(state.title == '新增'){
      const {confirmPassword,id,...data} = state.form

      data.password = Base64.encode(data.password)
      const res = await addStudent(data)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
        dialogVisible.value = false;
      }else{
        ElMessage.warning(res.message)
      }
    }else if(state.title == '编辑'){
      const {id, name, phone, sex, companyId, empno, post, duty,deptId, idNo,createId,createBy} = state.form
      const data = {id, name, phone, sex, companyId, empno, post, deptId, duty, idNo,createId,createBy}
      const res = await editStudent(data)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
      }else{
        ElMessage.warning(res.message)
      }
    }else{
      const {id,password} = state.form
      const data = {id,password}
      data.password = Base64.encode(data.password)
      const res = await resetPwd(data)
      if(res.code == 200){
        ElMessage.success(res.message)
        emit('getList')
        handleClose()
      }else{
        ElMessage.warning(res.message)
      }
    }
  }
}
const handleClose = () => {
  state.form = {
    id: null,
    name: '',
    phone: '',
    password: '',
    confirmPassword: '',
    sex: 0,
    companyId: null,
    empno: '',
    post: '',
    duty: '',
    idNo: '',
    createId: null,
    createBy: '',
    userType: null
  }
  superRef.value.clearValidate();
  superRef.value.resetFields()
  dialogVisible.value = false;
}


const selectValue = (val) => {
  // state.form.parentId = null;
  // state.form.parentName = null;
  state.deptUserList.forEach(item => {
    if(item.name === val){
      state.form.createId = item.id
    }
  })
}

const loading = ref(false)
const getDeptUserList = async (val)=>{
  let param = {}
  if(val != ""){
    param = {
      name: val,
      userType: 2,
      companyId: state.form.companyId
    }
  }else {
    param = {
      pageNum: 1,
      pageSize: 10,
      userType: 2,
      companyId: state.form.companyId
    }
  }
    loading.value = true;
    const res = await getUser(param)
    if (res.code == 200) {
      loading.value = false;
      state.deptUserList = res.data.list.map(item => {
        return {
          ...item,
          name: item.name + ' ('+ item.username +') '
        }
      })

    } else {
      ElMessage.warning(res.message)
    }
}



defineExpose({
  openDialog
});

</script>

<style scoped lang="scss">
.notice{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
  .file {
    display: flex;
    flex-direction: column;
    align-items: flex-start;
  }
}
</style>
